pub struct Builtins { /* private fields */ }Expand description
Store for all registered builtin commands
Implementations
Sourceimpl Builtins
impl Builtins
Sourcepub fn new() -> Self
pub fn new() -> Self
Initializes a builtin container with no registered builtins
You probably want to use Builtins::default() instead to get some sensible default
builtins to use, then override the ones you want
Sourcepub fn insert<I, B: Builtin + 'static>(
&mut self,
name: impl ToString,
builtin: impl IntoBuiltin<I, Builtin = B>,
)
pub fn insert<I, B: Builtin + 'static>( &mut self, name: impl ToString, builtin: impl IntoBuiltin<I, Builtin = B>, )
Insert a builtin command of the given name
If a builtin of the same name has been registered, it will be overwritten.