pub struct JobExitCtx {
pub exit_statuses: Vec<ExitStatus>,
}Expand description
Runs when a job is completed
Multiple jobs may have completed at the same time so a vector of exit statuses is returned
Fields
exit_statuses: Vec<ExitStatus>Trait Implementations
impl HookEventMarker for JobExitCtx