Struct Line

pub struct Line { /* private fields */ }
The shrs implementation of the Readline trait

It is advised to use this default implementation as it follows the shrs design philosophy and it will integrate much better with the rest of the shell.

Implementations

Source

impl Line

pub fn expand(&mut self, states: &mut States, event: &Event) -> Result<bool>

returns a bool whether input should still be handled