pub struct Line { /* private fields */ }Expand description
The shrs implementation of the Readline trait
It is advised to use this default implementation as it follows the shrs design philosophy and it will integrate much better with the rest of the shell.
Implementations