pub struct States { /* private fields */ }Implementations
Sourceimpl States
impl States
pub fn insert<S: 'static>(&mut self, res: S)
pub fn remove<S>() -> Option<S>
Sourcepub fn get<S: 'static>(&self) -> Ref<'_, S>
pub fn get<S: 'static>(&self) -> Ref<'_, S>
Get an immutable borrow of a state of a given type S from global state store. Will panic if a borrow exists or the type specified does not exist in the state store
Sourcepub fn try_get<S: 'static>(&self) -> Result<Ref<'_, S>, StateError>
pub fn try_get<S: 'static>(&self) -> Result<Ref<'_, S>, StateError>
Attempts to get an immutable borrow of a state of a given type S from global state store
Sourcepub fn get_mut<S: 'static>(&self) -> RefMut<'_, S>
pub fn get_mut<S: 'static>(&self) -> RefMut<'_, S>
Get a mutable borrow of a state of a given type S from global state store. Will panic if a borrow exists or the type specified does not exist in the state store
Sourcepub fn try_get_mut<S: 'static>(&self) -> Result<RefMut<'_, S>, StateError>
pub fn try_get_mut<S: 'static>(&self) -> Result<RefMut<'_, S>, StateError>
Attempts to get a mutable borrow of a state of a given type S from global state store